<?php
/* **************************************************** 
* 
* Plugin Name:	Tongue Theme Settings
* Description:	Settings for the GetSimple 3.1 Theme: Tongue
* Version:		1.3
* Author:		James Schindler-Ord
* Author URI:	http://james.schindler-ord.me.uk/
* 
**************************************************** */

# get correct id for plugin
$thisfile_tong=basename(__FILE__, ".php");
$tongue_file=GSDATAOTHERPATH .'TongueSettings.xml';

# add in this plugin's language file
i18n_merge($thisfile_tong,'en_US');

# register plugin
register_plugin(
	$thisfile_tong, 										# ID of plugin, should be filename minus php
	i18n_r($thisfile_tong.'/TONGUE_TITLE'), 				# Title of plugin
	'1.2', 													# Version of plugin
	'James Schindler-Ord',									# Author of plugin
	'http://james.schindler-ord.me.uk/', 					# Author URL
	i18n_r($thisfile_tong.'/TONGUE_DESC'), 					# Plugin Description
	'theme', 												# Page type of plugin
	'tongue_show'  											# Function that displays content
);



# hooks
add_action('theme-sidebar','createSideMenu',array($thisfile_tong, i18n_r($thisfile_tong.'/TONGUE_TITLE'))); 

# get XML data
if (file_exists($tongue_file)) {
	$x = getXML($tongue_file);
	$logo = $x->logo;
	$adsense_id = $x->adsense_id;
	$adsense_side = $x->adsense_side;
	$adsense_main = $x->adsense_main;
} else {
	$logo = '';
	$adsense_id = '';
	$adsense_side = '';
	$adsense_main = '';
}


function tongue_show() {
	global $tongue_file, $logo, $adsense_id, $adsense_side, $adsense_main, $thisfile_tong;
	$success=null;$error=null;
	
	// submitted form
	if (isset($_POST['submit'])) {
		$logo=null; $adsense_id=null; $adsense_side=null; $adsense_main=null;
		
		# check to see if the URLs provided are valid
		if ($_POST['logo'] != '') {
			if (validate_url($_POST['logo'])) {
				$logo = $_POST['logo'];
			} else {
				$error .= i18n_r($thisfile_tong.'/LOGO_ERROR').' ';
			}
		}
		
		# 
		$adsense_id = $_POST['adsense_id'];
		$adsense_side = $_POST['adsense_side'];
		$adsense_main = $_POST['adsense_main'];
		
		# if there are no errors, save data
		if (!$error) {
			$xml = @new SimpleXMLElement('<item></item>');
			$xml->addChild('logo', $logo);
			$xml->addChild('adsense_id', $adsense_id);
			$xml->addChild('adsense_side', $adsense_side);
			$xml->addChild('adsense_main', $adsense_main);

			
			if (! $xml->asXML($tongue_file)) {
				$error = i18n_r('CHMOD_ERROR');
			} else {
				$x = getXML($tongue_file);
				$logo = $x->logo;
				$adsense_id = $x->adsense_id;
				$adsense_side = $x->adsense_side;
				$adsense_main = $x->adsense_main;
				$success = i18n_r('SETTINGS_UPDATED');
			}
		}
	}
	
	?>
	<h3><?php i18n($thisfile_tong.'/TONGUE_TITLE'); ?></h3>
	
	<?php 
	if($success) { 
		echo '<p style="color:#669933;"><b>'. $success .'</b></p>';
	} 
	if($error) { 
		echo '<p style="color:#cc0000;"><b>'. $error .'</b></p>';
	}
	?>
	
	<form method="post" action="<?php	echo $_SERVER ['REQUEST_URI']?>">
		
		<p><label for="ton_logo" ><?php i18n($thisfile_tong.'/LOGO_URL'); ?></label><input id="ton_logo" name="logo" class="text" value="<?php echo $logo; ?>" /></p>
		
		<p><label for="ton_adsense_id" ><?php i18n($thisfile_tong.'/ADSENSE_ID'); ?></label><input id="ton_adsense_id" name="adsense_id" class="text" value="<?php echo $adsense_id; ?>" /></p>

		<p>
		<label for="ton_adsense_side" ><?php i18n($thisfile_tong.'/ADSENSE_SIDE'); ?></label>
		<?php if ($adsense_side == 1) { ?>
		<input type="radio" id="ton_adsense_side" name="adsense_side" class="radio" value="1" checked="checked" />On
		<input type="radio" id="ton_adsense_side" name="adsense_side" class="radio" value="0" />Off
		<?php } else { ?>
		<input type="radio" id="ton_adsense_side" name="adsense_side" class="radio" value="1" />On
		<input type="radio" id="ton_adsense_side" name="adsense_side" class="radio" value="0" checked="checked" />Off
		<?php } ?>
		</p>

		<p>
		<label for="ton_adsense_main" ><?php i18n($thisfile_tong.'/ADSENSE_MAIN'); ?></label>
		<?php if ($adsense_main == 1) { ?>
		<input type="radio" id="ton_adsense_main" name="adsense_main" class="radio" value="1" checked="checked" />On 
		<input type="radio" id="ton_adsense_main" name="adsense_main" class="radio" value="0" />Off
		<?php } else { ?>
		<input type="radio" id="ton_adsense_main" name="adsense_main" class="radio" value="1" />On 
		<input type="radio" id="ton_adsense_main" name="adsense_main" class="radio" value="0" checked="checked" />Off
		<?php } ?>
		</p>
		
		<p><input type="submit" id="submit" class="submit" value="<?php i18n('BTN_SAVESETTINGS'); ?>" name="submit" /></p>
	</form>
	
	<?php
}
